pyelectro
=========

[![GH Build](https://github.com/NeuralEnsemble/pyelectro/actions/workflows/ci.yml/badge.svg)](https://github.com/NeuralEnsemble/pyelectro/actions/workflows/ci.yml)
[![Documentation Status](https://readthedocs.org/projects/pyelectro/badge/?version=latest)](https://pyelectro.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/pyelectro)](https://pypi.org/project/pyelectro/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyelectro)](https://pypi.org/project/pyelectro/)
[![GitHub](https://img.shields.io/github/license/NeuralEnsemble/pyelectro)](https://github.com/NeuralEnsemble/pyelectro/blob/master/LICENSE)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/NeuralEnsemble/pyelectro)](https://github.com/NeuralEnsemble/pyelectro/pulls)
[![GitHub issues](https://img.shields.io/github/issues/NeuralEnsemble/pyelectro)](https://github.com/NeuralEnsemble/pyelectro/issues)
[![GitHub Org's stars](https://img.shields.io/github/stars/NeuralEnsemble?style=social)](https://github.com/NeuralEnsemble)

Tool for analysis of electrophysiology in Python.

**This package was originally developed by [Mike Vella](https://github.com/vellamike). This has been updated by [Padraig Gleeson](https://github.com/pgleeson) and others (and moved to [NeuralEnsemble](https://github.com/NeuralEnsemble)) to continue development of [pyelectro](https://github.com/NeuralEnsemble/pyelectro) and [Neurotune](https://github.com/NeuralEnsemble/neurotune) for use in [OpenWorm](http://www.openworm.org/), [Open Source Brain](http://opensourcebrain.org/) and other projects**
